# Todo

## To Do

[ ] Add logging
[ ] Add documentation

## In Progress

[ ] Add comments to the code
[ ] Improve code structure

## Completed

[x] Improve command line arguments - 2026-03-07
[x] Add help message for command line arguments that do not already have them - 2026-03-07
